@@ -656,4 +656,27 @@ Clazz.defineMethod (c$, "getDataRange",
 function () {
 return (this.jvxlData.jvxlPlane != null && this.colorEncoder == null ? null :  Clazz.newFloatArray (-1, [this.jvxlData.mappedDataMin, this.jvxlData.mappedDataMax, (this.jvxlData.isColorReversed ? this.jvxlData.valueMappedToBlue : this.jvxlData.valueMappedToRed), (this.jvxlData.isColorReversed ? this.jvxlData.valueMappedToRed : this.jvxlData.valueMappedToBlue)]));
 });
+Clazz.defineMethod (c$, "getInfo", 
+function (isAll) {
+var info = Clazz.superCall (this, J.shapesurface.IsosurfaceMesh, "getInfo", [isAll]);
+if (isAll) {
+var excluded = this.jvxlData.jvxlExcluded;
+var invalid = excluded[1];
+var thisSet = this.jvxlData.thisSet;
+var bs =  new JU.BS ();
+if (invalid != null) bs.or (invalid);
+if (thisSet != null) {
+for (var i = this.vc; --i >= 0; ) {
+if (!thisSet.get (this.vertexSets[i])) bs.set (i);
+}
+}var n = this.vc - bs.cardinality ();
+if (n != this.vc) {
+var pa =  new Array (n);
+for (var pt = 0, i = bs.nextClearBit (0); i >= 0 && pt < n; i = bs.nextClearBit (i + 1)) {
+pa[pt++] = this.vs[i];
+}
+info.put ("allVertices", info.get ("vertices"));
+info.put ("vertices", pa);
+}}return info;
+}, "~B");
 });
